@@ -73,7 +73,7 @@ themes.view.Appearance = wp.Backbone.View.extend({
 		this.SearchView = options.SearchView ? options.SearchView : themes.view.Search;
 		// Bind to the scroll event and throttle
 		// the results from this.scroller.
-		this.window.bind( 'scroll', _.throttle( this.scroller, 300 ) );
+		this.window.on( 'scroll', _.throttle( this.scroller, 300 ) );
 	},
 
 	// Main render control.
@@ -404,11 +404,7 @@ themes.view.Theme = wp.Backbone.View.extend({
 		var data = this.model.toJSON();
 
 		// Render themes using the html template.
-		this.$el.html( this.html( data ) ).attr({
-			tabindex: 0,
-			'aria-describedby' : data.id + '-action ' + data.id + '-name',
-			'data-slug': data.id
-		});
+		this.$el.html( this.html( data ) ).attr( 'data-slug', data.id );
 
 		// Renders active theme styles.
 		this.activeTheme();
@@ -550,7 +546,7 @@ themes.view.Theme = wp.Backbone.View.extend({
 			// Render and append.
 			preview.render();
 			this.setNavButtonsState();
-			$( '.next-theme' ).focus();
+			$( '.next-theme' ).trigger( 'focus' );
 		})
 		.listenTo( preview, 'theme:previous', function() {
 
@@ -580,7 +576,7 @@ themes.view.Theme = wp.Backbone.View.extend({
 			// Render and append.
 			preview.render();
 			this.setNavButtonsState();
-			$( '.previous-theme' ).focus();
+			$( '.previous-theme' ).trigger( 'focus' );
 		});
 
 		this.listenTo( preview, 'preview:close', function() {
@@ -602,7 +598,7 @@ themes.view.Theme = wp.Backbone.View.extend({
 				.addClass( 'disabled' )
 				.prop( 'disabled', true );
 
-			nextThemeButton.focus();
+			nextThemeButton.trigger( 'focus' );
 		}
 
 		// Disable next if the next model is undefined.
@@ -611,7 +607,7 @@ themes.view.Theme = wp.Backbone.View.extend({
 				.addClass( 'disabled' )
 				.prop( 'disabled', true );
 
-			previousThemeButton.focus();
+			previousThemeButton.trigger( 'focus' );
 		}
 	},
 
@@ -626,6 +622,9 @@ themes.view.Theme = wp.Backbone.View.extend({
 			if ( _this.model.get( 'id' ) === response.slug ) {
 				_this.model.set( { 'installed': true } );
 			}
+			if ( response.blockTheme ) {
+				_this.model.set( { 'block_theme': true } );
+			}
 		} );
 
 		wp.updates.installTheme( {
@@ -705,7 +704,7 @@ themes.view.Details = wp.Backbone.View.extend({
 
 		// Set initial focus on the primary action control.
 		_.delay( function() {
-			$( '.theme-overlay' ).focus();
+			$( '.theme-overlay' ).trigger( 'focus' );
 		}, 100 );
 
 		// Constrain tabbing within the modal.
@@ -716,10 +715,10 @@ themes.view.Details = wp.Backbone.View.extend({
 			// Check for the Tab key.
 			if ( 9 === event.which ) {
 				if ( $firstFocusable[0] === event.target && event.shiftKey ) {
-					$lastFocusable.focus();
+					$lastFocusable.trigger( 'focus' );
 					event.preventDefault();
 				} else if ( $lastFocusable[0] === event.target && ! event.shiftKey ) {
-					$firstFocusable.focus();
+					$firstFocusable.trigger( 'focus' );
 					event.preventDefault();
 				}
 			}
@@ -764,7 +763,7 @@ themes.view.Details = wp.Backbone.View.extend({
 
 				// Return focus to the theme div.
 				if ( themes.focusedTheme ) {
-					themes.focusedTheme.focus();
+					themes.focusedTheme.find('.more-details').trigger( 'focus' );
 				}
 			});
 		}
@@ -952,7 +951,7 @@ themes.view.Preview = themes.view.Details.extend({
 
 			// Return focus to the theme div.
 			if ( themes.focusedTheme ) {
-				themes.focusedTheme.focus();
+				themes.focusedTheme.find('.more-details').trigger( 'focus' );
 			}
 		}).removeClass( 'iframe-ready' );
 
@@ -1695,7 +1694,13 @@ themes.view.Installer = themes.view.Appearance.extend({
 	browse: function( section ) {
 		// Create a new collection with the proper theme data
 		// for each section.
-		this.collection.query( { browse: section } );
+		if ( 'block-themes' === section ) {
+			// Get the themes by sending Ajax POST request to api.wordpress.org/themes
+			// or searching the local cache.
+			this.collection.query( { tag: 'full-site-editing' } );
+		} else {
+			this.collection.query( { browse: section } );
+		}
 	},
 
 	// Sorting navigation.
@@ -1965,7 +1970,7 @@ themes.RunInstaller = {
 		// Set up the view.
 		// Passes the default 'section' as an option.
 		this.view = new themes.view.Installer({
-			section: 'featured',
+			section: 'popular',
 			SearchView: themes.view.InstallerSearch
 		});
 
@@ -2032,12 +2037,12 @@ themes.RunInstaller = {
 		/*
 		 * Handles sorting / browsing routes.
 		 * Also handles the root URL triggering a sort request
-		 * for `featured`, the default view.
+		 * for `popular`, the default view.
 		 */
 		themes.router.on( 'route:sort', function( sort ) {
 			if ( ! sort ) {
-				sort = 'featured';
-				themes.router.navigate( themes.router.baseUrl( '?browse=featured' ), { replace: true } );
+				sort = 'popular';
+				themes.router.navigate( themes.router.baseUrl( '?browse=popular' ), { replace: true } );
 			}
 			self.view.sort( sort );
 
@@ -2049,7 +2054,7 @@ themes.RunInstaller = {
 
 		// The `search` route event. The router populates the input field.
 		themes.router.on( 'route:search', function() {
-			$( '.wp-filter-search' ).focus().trigger( 'keyup' );
+			$( '.wp-filter-search' ).trigger( 'focus' ).trigger( 'keyup' );
 		});
 
 		this.extraRoutes();
@@ -2061,7 +2066,7 @@ themes.RunInstaller = {
 };
 
 // Ready...
-$( document ).ready(function() {
+$( function() {
 	if ( themes.isInstall ) {
 		themes.RunInstaller.init();
 	} else {
@@ -2089,7 +2094,7 @@ $( document ).ready(function() {
 })( jQuery );
 
 // Align theme browser thickbox.
-jQuery(document).ready( function($) {
+jQuery( function($) {
 	window.tb_position = function() {
 		var tbWindow = $('#TB_window'),
 			width = $(window).width(),
@@ -2101,7 +2106,7 @@ jQuery(document).ready( function($) {
 			adminbar_height = parseInt( $('#wpadminbar').css('height'), 10 );
 		}
 
-		if ( tbWindow.size() ) {
+		if ( tbWindow.length >= 1 ) {
 			tbWindow.width( W - 50 ).height( H - 45 - adminbar_height );
 			$('#TB_iframeContent').width( W - 50 ).height( H - 75 - adminbar_height );
 			tbWindow.css({'margin-left': '-' + parseInt( ( ( W - 50 ) / 2 ), 10 ) + 'px'});
@@ -2111,5 +2116,5 @@ jQuery(document).ready( function($) {
 		}
 	};
 
-	$(window).resize(function(){ tb_position(); });
+	$(window).on( 'resize', function(){ tb_position(); });
 });
